#! /bin/bash

#export LANG=C

set -u

WARNDAYS=1
CRITDAYS=2

DAR_STATUS_PATTERN_OK='0|11'
DAR_STATUS_PATTERN_WARNING='-'

VERBOSE=false
status=""



# Nagios return codes
STATE_OK=0
STATE_WARNING=1
STATE_CRITICAL=2
STATE_UNKNOWN=3
STATE_DEPENDENT=4


while (($# > 0)); do
	case "$1" in
	-w)	shift; WARNDAYS=$1
	;;
	-c)	shift; CRITDAYS=$1
	;;
	-v)	VERBOSE=true
	;;
	*)	echo 'unkown option'
		exit $STATE_CRITICAL
	esac
	shift
done

if [ "$WARNDAYS" -gt "$CRITDAYS" ] ; then
	echo "WARNDAYS greater than CRITDAYS"
	exit $STATE_CRITICAL
fi

if [ -e /etc/dar-backup/dar-backup.conf ]; then
 . /etc/dar-backup/dar-backup.conf
 if [ -e /etc/dar-backup/dar-exclude.conf ]; then
  . /etc/dar-backup/dar-exclude.conf
 fi
elif [ -e /etc/backup-full.conf ]; then
 . /etc/backup-full.conf
else
 echo "No config file found for $0" >2
 exit $STATE_CRITICAL
fi

if [ "x$CURLFS"!="x" ]; then
  if ! ( df -P | awk '$1 ~ /curlftpfs/ { print $6 }' | grep $CURLFS > /dev/null ); then
    curlftpfs -o user=$FTPUSER:$FTPPASS $FTPSERVER $CURLFS || exit $STATE_CRITICAL
  fi
fi

dar_status_explain () {

	if ! [ -f "$1"  ] ; then
		echo 'bad'
	elif  egrep -q "$DAR_STATUS_PATTERN_OK" "$1" ; then
		echo 'good'
	elif egrep -q "$DAR_STATUS_PATTERN_WARNING" "$1" ; then
		echo 'dont know'
	else
		echo 'bad'
	fi
}


cd /$BACKUPDIR || exit $STATE_CRITICAL
lastgoodstatefile=`egrep -l "$DAR_STATUS_PATTERN_OK"  [2-9][0-9][0-9][0-9]-[0-9][0-9]-[0-9][0-9]/status 2>/dev/null | tail -1`
if [ -z "$lastgoodstatefile" ]; then
	echo "no good backup  found"
	status=$STATE_CRITICAL
else
	lastgoodtime=`date -r $lastgoodstatefile`
	lastgoodtime_s=`date -d "$lastgoodtime" +%s`
	now=`date +%s`
	
	#echo -n "last good backup ($lastgoodtime)"
	echo -n "last good backup (`dirname $lastgoodstatefile`, endtime $lastgoodtime)"
	if [ $((now-lastgoodtime_s)) -gt $((CRITDAYS*3600*24)) ]; then
		echo -n " is older than $CRITDAYS days"
		status=$STATE_CRITICAL
	elif [ $((now-lastgoodtime_s)) -gt $((WARNDAYS*3600*24)) ]; then
		echo -n " is older than $WARNDAYS days"
		status=$STATE_WARNING
	else
		status=$STATE_OK
	fi
	echo ", dar-status: `cat $lastgoodstatefile`"
fi

if $VERBOSE ; then
	for d in [2-9][0-9][0-9][0-9]-[0-9][0-9]-[0-9][0-9]; do
		st=`cat $d/status 2>/dev/null`
		echo -n "$d: `du -sh $d | cut -f1` dar-status: $st"
		echo " (`dar_status_explain "$d/status"`)"
	done
fi

exit $status

